#ProcessorAdvisory.py
'''Functions to process the advisory component.'''

import logging

# gitlab projects
# TODO: Package these projects so they are robust for importing
from ews.coordinator.processor_base import ProcessorBase
from ews.advisory_builder import data_gatherer
from ews.coordinator.utils.processor_utils import short_name


class ProcessorAdvisory(ProcessorBase):

    def process_pre_job(self, args) -> bool:
        # return self.process_pre_job_advisory(args)
        return True


    def process_in_job(self, jobPath, status, configjson, component) -> object:
        return self.process_in_job_advisory(jobPath, status, configjson, component)


    def process_post_job(self, jobPath, configjson):
        pass


    def __init__(self) -> None:
        super().__init__()


    def process_in_job_advisory(self, jobPath, status, config, component):
        '''Generates a word processor file containing some basic survey statistics
        and output figures from deposition, environmental suitability, and
        eventually also the epi model. This template advisory is intended to speed
        up the process of writing advisories. The intended user is a local expert
        who edits the content of the document.
        Uses the gitlab project EWS-advisory-builder.'''

        config_advisory = config[component].copy()

        config_advisory['jobPath'] = jobPath

        # provide top-level arguments to advisory config
        for k,v in config.items():
            if k not in short_name.keys():
                config_advisory[k]=v

        dateString = config['StartString']

        layout = 'tight'

        logging.info(f"Running for scenario {config_advisory}, {dateString}, {layout}")

        report_names = data_gatherer.run_each_subregion(config_advisory, dateString, layout)

        # pass the report filenames to upload to the remote server

        proc_out = {}
        # Output files available for upload
        proc_out['output'] = report_names
        # Processing files available for clearing
        proc_out['clearup'] = None

        return proc_out


if __name__ == '__main__':
    processor = ProcessorAdvisory()
    processor.run_processor("Advisory", "ADVISORY")
